SequenceGenerator

Struct SequenceGenerator 

pub struct SequenceGenerator;
Generates monotonically increasing i64 values. Note that only values >= 0 will be returned such that any negative value can be assumed to be invalid.

Provides implementations of:

  • Generator - returns increasing i64 values.
  • GeneratorWithInvalid - returns an invalid, as an ID, i64 value.
  • GeneratorFromStr - ensures validity of a string representation as an i64 ID.
  • GeneratorFromSeed - initializes the generator with a known seed value.